import { PoolConfig } from 'pg';
import { BaseDriver, DownloadQueryResultsOptions, DownloadTableMemoryData, DriverInterface, IndexesSQL, TableStructure, QueryOptions } from '@cubejs-backend/query-orchestrator';
import { QuestQuery } from './QuestQuery';
export declare type QuestDriverConfiguration = Partial<PoolConfig> & {
    readOnly?: boolean;
};
export declare class QuestDriver<Config extends QuestDriverConfiguration = QuestDriverConfiguration> extends BaseDriver implements DriverInterface {
    private readonly pool;
    private readonly config;
    static dialectClass(): typeof QuestQuery;
    constructor(config?: Partial<Config>);
    private getInitialConfiguration;
    testConnection(): Promise<void>;
    private mapFields;
    query<R = unknown>(query: string, values: unknown[], _options?: QueryOptions): Promise<R[]>;
    private queryResponse;
    private getTypeParser;
    downloadQueryResults(query: string, values: unknown[], _options: DownloadQueryResultsOptions): Promise<{
        rows: any[];
        types: {
            name: string;
            type: string;
        }[];
    }>;
    createSchemaIfNotExists(_schemaName: string): Promise<any>;
    tablesSchema(): Promise<Record<string, Record<string, object>>>;
    getTablesQuery(_schemaName: string): Promise<({
        table_name?: string;
        TABLE_NAME?: string;
    })[]>;
    tableColumnTypes(table: string): Promise<{
        name: any;
        type: string;
    }[]>;
    uploadTableWithIndexes(table: string, columns: TableStructure, tableData: DownloadTableMemoryData, indexesSql: IndexesSQL): Promise<void>;
    readOnly(): boolean;
    release(): Promise<void>;
    param(paramIndex: number): string;
}
//# sourceMappingURL=QuestDriver.d.ts.map